#
# spec file for package xf86-input-vmmouse
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%( test -d %{_prefix}/lib/udev/rules.d && echo "1" ) > 0
%define _udevrulesdir %{_prefix}/lib/udev/rules.d
%else
%define _udevrulesdir /lib/udev/rules.d
%endif
Name:           xf86-input-vmmouse
Version:        13.2.0
Release:        2.2
Summary:        VMware Mouse input driver for the Xorg X server
License:        MIT
Group:          System/X11/Servers/XF86_4
URL:            https://xorg.freedesktop.org/
Source0:        http://xorg.freedesktop.org/releases/individual/driver/%{name}-%{version}.tar.xz
Source1:        http://xorg.freedesktop.org/releases/individual/driver/%{name}-%{version}.tar.xz.sig
Source2:        %{name}.keyring
Patch2:         u_Don-t-access-hardware-register-while-switched-away.patch
Patch3:         u_conf-rename-to-70-vmmouse.conf.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(inputproto)
BuildRequires:  pkgconfig(libudev)
BuildRequires:  pkgconfig(randrproto)
BuildRequires:  pkgconfig(udev)
BuildRequires:  pkgconfig(xorg-macros) >= 1.8
BuildRequires:  pkgconfig(xorg-server) >= 1.0.1
BuildRequires:  pkgconfig(xproto)
Requires:       udev
# This was part of the xorg-x11-driver-input package up to version 7.6
Conflicts:      xorg-x11-driver-input <= 7.6
ExclusiveArch:  %{ix86} x86_64
%{x11_abi_xinput_req}
# no longer install this driver by default with kernel >= 4.1.x (fate #320612)
%if 0%{?suse_version} <= 1320 && !(0%{?suse_version} == 1315 && 0%{?is_opensuse})
Supplements:    xorg-x11-server
%endif

%description
vmmouse is an Xorg input driver for mice. The driver supports most
available mouse types and interfaces. USB mice are only supported on
some OSs, and the level of support for PS/2 mice depends on the OS.

%prep
%autosetup -p1

%build
autoreconf -fi
%configure --with-xorg-conf-dir=%{_datadir}/X11/xorg.conf.d/ --with-udev-rules-dir=%{_udevrulesdir}
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print
# Drop hal support
rm %{buildroot}%{_datadir}/hal/fdi/policy/20thirdparty/11-x11-vmmouse.fdi
rm %{buildroot}%{_libdir}/hal/hal-probe-vmmouse

%post
# re-plug the input devices
udevadm trigger --subsystem-match=input --action=change || :
exit 0

%postun
# re-plug the input devices
udevadm trigger --subsystem-match=input --action=change || :
exit 0

%files
%license COPYING
%doc ChangeLog README
%{_udevrulesdir}/69-xorg-vmmouse.rules
%dir %{_datadir}/X11/xorg.conf.d/
%{_datadir}/X11/xorg.conf.d/70-vmmouse.conf
%dir %{_libdir}/xorg/modules/input
%{_libdir}/xorg/modules/input/vmmouse_drv.so
%{_bindir}/vmmouse_detect
%{_mandir}/man1/vmmouse_detect.1%{?ext_man}
%{_mandir}/man4/vmmouse.4%{?ext_man}

%changelog
* Mon Feb 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  PatchN.
* Mon Oct 17 2022 Stefan Dirsch <sndirsch@suse.com>
- xf86-input-vmmouse 13.2.0:
  * Update "See Also" list in vmmouse_detect man page
  * Update configure.ac bug URL for gitlab migration
  * gitlab CI: add a basic build test
  * autogen.sh: Implement GNOME Build API
  * autogen.sh: use quoted string variables
  * tools: Fix declaration of xf86EnableIO()
  * autogen: add default patch prefix
  * Drop maintainer mode from autogen.sh
  * autogen.sh: use exec instead of waiting for configure to finish
  * Replace unportable test(1) operator.
  * Add NetBSD/amd64 support for iopl calls.
* Fri Mar 12 2021 Dirk Müller <dmueller@suse.com>
- modernize spec file (move licenses to licensedir)
* Tue Jul 30 2019 Stefan Dirsch <sndirsch@suse.com>
- move xorg.conf.d snippet from /etc/X11/xorg.conf.d to
  /usr/share/X11/xorg.conf.d (boo#1139692)
* Tue May 30 2017 sndirsch@suse.com
- includes everything needed for missing sle issue entries:
  fate #320612, fate #315643-315645, 319159-319161, 319618, bnc#922188
  (bsc#1041589)
* Fri Jun 10 2016 sndirsch@suse.com
- u_conf-rename-to-70-vmmouse.conf.patch
  * renamed config file to give it higher prio than libinput;
    relevant only for older kernels; on newer kernels vmmouse
    driver isn't loaded at all (bnc#983702, comment#20)
* Fri Mar  4 2016 sndirsch@suse.com
- no longer install the driver package by default on openSUSE > 13.2
  or Leap, i.e. remove the supplements to xorg-x11-server
  (fate #320612)
* Sun Sep 27 2015 mpluskal@suse.com
- Add gpg signature
* Fri Jul 31 2015 dimstar@opensuse.org
- BuildRequire pkgconfig(udev) instead of udev: be more robust to
  packaging changes.
- Ignore absence of udevadm, it won't be present in the build env.
* Fri Jun 26 2015 sndirsch@suse.com
- xf86-input-vmmouse 13.1.0:
  This release is intended for general distro inclusion, Testing
  has been performed on various linux distros, FreeBSD 10.1 and
  Solaris 11.2.
  This release contains a number of build fixes and also changes
  to deal with improved vmmouse port security and backoff if a
  vmmouse kernel module is encountered. An additional dependency
  on libudev is introduced on linux.
- supersedes the following patches:
  * U_Don-t-de-reference-pMse-if-it-hasn-t-been-initialise.patch
  * U_Free-the-vmmouse-data-on-UnInit.patch
  * u_Revert-Remove-call-to-iopl-.-It-s-not-portable-and-i.patch
  * u_vmmouse_client.h-Include-xorg-server.h-before-xf86_O.patch
* Wed Mar 18 2015 sndirsch@suse.com
- U_Don-t-de-reference-pMse-if-it-hasn-t-been-initialise.patch
  * fixes X server crash being started by valgrind (bnc#922188)
* Mon Oct  6 2014 sndirsch@suse.com
- u_vmmouse_client.h-Include-xorg-server.h-before-xf86_O.patch
  * include xorg-server.h before xf86_OSproc.h in order to fix
    build with latest glibc
* Tue May 27 2014 eich@suse.com
- U_Free-the-vmmouse-data-on-UnInit.patch:
  Delete driver from xf86InputDevs list on UnInit().
  Fixes crash during VT switch when reloading the devices
  (bnc#879450).
* Tue May 27 2014 eich@suse.com
- u_Don-t-access-hardware-register-while-switched-away.patch:
  Update patch to also take into account new ABI versions.
  (bnc#877132).
* Tue May 13 2014 eich@suse.com
- u_Don-t-access-hardware-register-while-switched-away.patch:
  Avoid crash when vmmouse is hotplugged while switched away
  (bnc#877132).
* Thu Feb 13 2014 tiwai@suse.de
- u_Revert-Remove-call-to-iopl-.-It-s-not-portable-and-i.patch:
  Revert iopl() removal that broke vmmouse on QEMU/KVM (bnc#863750)
* Fri Jan 10 2014 coolo@suse.com
- fix udev checking to also work if build service throws udev-mini
  at the build
* Fri Aug 30 2013 sndirsch@suse.com
- dropped xf86-input-vmmouse-iopl.diff; meanwhile resolved upstream
  fixing bnc#625041 in a better way, not causing bnc#743401
* Thu Jan 24 2013 sndirsch@suse.com
- xf86-input-vmmouse 13.0.0
  * Bugfix release for Xserver 1.13. Well tested by our QE so it's
    advisable to upgrade.
* Wed Oct 17 2012 fcrozat@suse.com
- Fix build with new udev rules directory location.
* Sat May 26 2012 zaitor@opensuse.org
- Update to version 12.9.0:
  + Revert "Adjust the kernel name in the udev file."
  + config: replace obsolete AM_CONFIG_HEADER with
    with AC_CONFIG_HEADERS.
  + Enable hardware access during vmmouse preinit.
* Thu Apr 19 2012 dimstar@opensuse.org
- Update to version 12.8.0:
  + Adjust the kernel name in the udev file.
  + Deal with opaque InputOption types in ABI 14
- Use %%x11_abi_xinput_req instead of static ABI Requires.
* Wed Apr 18 2012 vuntz@opensuse.org
- Split xf86-input-vmmouse from xorg-x11-driver-input.
  Initial version: 12.7.0.
